@@ -18,11 +18,11 @@ hr_gpkg <- file.path(work_dir, "hr_data.gpkg")
 if(!exists("layers")) {
   layers <- NULL
 }
-
-hr_data <- get_nhdplushr(work_dir, layers = layers,
-                         out_gpkg = hr_gpkg,
-                         pattern = "03_sub.gpkg")
-
+suppressWarnings(
+  hr_data <- nhdplusTools::get_nhdplushr(work_dir, layers = layers,
+                                         out_gpkg = hr_gpkg,
+                                         pattern = "03_sub.gpkg")
+)
 # hr_catchment <- sf::read_sf(hr_path, "NHDPlusCatchment")
 # hr_catchment <- sf::st_transform(hr_catchment, proj)
 #
