@@ -1,4 +1,19 @@
+test_that("get_sorted error", {
+  test_data <- data.frame(id = c(1, 2, 3, 4, 6, 7, 8, 9),
+                          toid = c(2, 3, 4, 9, 7, 8, 9, 4))
 
+  expect_error(nhdplusTools::get_sorted(test_data))
+
+  test_data <- data.frame(id = c(1, 2, 3, 4, 6, 7, 8, 9),
+                          toid = c(2, 3, 4, 0, 7, 8, 9, 4))
+
+  expect_equal(nrow(nhdplusTools::get_sorted(test_data)), nrow(test_data))
+
+  test_data <- data.frame(id = c(1, 2, 3, 4),
+                          toid = c(2, 3, 4, 0))
+
+  expect_equal(nrow(nhdplusTools::get_sorted(test_data)), nrow(test_data))
+})
 
 test_that("total drainage area works", {
   source(system.file("extdata", "walker_data.R", package = "nhdplusTools"))
